@@ -39,7 +39,7 @@
         <location filename="mainwindow.ui" line="215"/>
         <location filename="ui_mainwindow.h" line="762"/>
         <source>Active interface</source>
-        <translation>Interface activa</translation>
+        <translation>Interface ativa</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="231"/>
@@ -51,7 +51,7 @@
         <location filename="mainwindow.ui" line="253"/>
         <location filename="ui_mainwindow.h" line="767"/>
         <source>Unblocks all soft/hard blocked wireless devices</source>
-        <translation>Desbloqueia todos os dispositivos sem fios (wireless) bloqueados por software ou no equipamento (soft/hard blocked)</translation>
+        <translation>Desbloqueia todos os dispositivos sem fios (wireless) bloqueados por programa/software ou no equipamento (soft/hard blocked)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="256"/>
@@ -87,7 +87,7 @@
         <location filename="mainwindow.ui" line="409"/>
         <location filename="ui_mainwindow.h" line="775"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>Bloquear controlador</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="428"/>
@@ -99,7 +99,7 @@
         <location filename="mainwindow.ui" line="434"/>
         <location filename="ui_mainwindow.h" line="777"/>
         <source>Available Windows drivers</source>
-        <translation>Controladores Windows disponíveis</translation>
+        <translation>Controladores do Windows disponíveis</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="468"/>
@@ -123,7 +123,7 @@
         <location filename="mainwindow.ui" line="532"/>
         <location filename="ui_mainwindow.h" line="782"/>
         <source>Install NDISwrapper</source>
-        <translation>Instalar NDISwrapper&gt;</translation>
+        <translation>Instalar NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="543"/>
@@ -135,7 +135,7 @@
         <location filename="mainwindow.ui" line="559"/>
         <location filename="ui_mainwindow.h" line="784"/>
         <source>Uninstall NDISwrapper</source>
-        <translation>Desinstalar o NDISwrapper&gt;</translation>
+        <translation>Desinstalar o NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="591"/>
@@ -226,7 +226,7 @@
     <message>
         <location filename="mainwindow.cpp" line="87"/>
         <source>IP address from router:</source>
-        <translation>Endereço IP do encaminhador (router)</translation>
+        <translation>Endereço IP do roteador (router)</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="88"/>
@@ -265,7 +265,7 @@
         <location filename="mainwindow.cpp" line="261"/>
         <location filename="mainwindow.cpp" line="278"/>
         <source>Traceroute not installed</source>
-        <translation>O Traceroute não está instalado&gt;</translation>
+        <translation>O Traceroute não está instalado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="262"/>
@@ -280,12 +280,12 @@
     <message>
         <location filename="mainwindow.cpp" line="270"/>
         <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
-        <translation>Não foi possível instalar o Traceroute. Isto pode resultar de estar a usar a instalação externa ou de não se conseguir ligar ao repositório de software.</translation>
+        <translation>Não foi possível instalar o Traceroute. Isto pode significar que você está usando a instalação externa ou de não se conseguir acessar o repositório de programas/softwares.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="279"/>
         <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
-        <translation>O Traceroute não está instalado. Não foi detectada nenhuma ligação à Internet, pelo que não é possível proceder à sua instalação</translation>
+        <translation>O Traceroute não está instalado. Não foi detectado nenhuma conexão com a Internet, portanto, não pode ser instalado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="285"/>
@@ -297,7 +297,7 @@
         <location filename="mainwindow.cpp" line="286"/>
         <location filename="mainwindow.cpp" line="327"/>
         <source>Please fill in the destination host field</source>
-        <translation>Preencha o campo do hospedeiro de destino</translation>
+        <translation>Por favor, preencha o campo do hospedeiro (host) de destino</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="440"/>
@@ -312,22 +312,22 @@
     <message>
         <location filename="mainwindow.cpp" line="464"/>
         <source>Blocked Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Controladores bloqueados</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="486"/>
         <source>Blocked Broadcom Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Controladores Broadcom bloqueados</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="894"/>
         <source>enabled</source>
-        <translation>activado</translation>
+        <translation>ativado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="897"/>
         <source>disabled</source>
-        <translation>desactivado</translation>
+        <translation>desativado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="900"/>
@@ -342,27 +342,27 @@
     <message>
         <location filename="mainwindow.cpp" line="908"/>
         <source>Windows installation information file (*.inf)</source>
-        <translation>Ficheiro de informação sobre a instalação Windows (*.inf)</translation>
+        <translation>Arquivo de informação sobre a instalação Windows (*.inf)</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="939"/>
         <source>*.sys file not found</source>
-        <translation>Não foi encontrado o ficheiro *.sys</translation>
+        <translation>Não foi encontrado o arquivo  *.sys</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="939"/>
         <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
-        <translation>Os ficheiros *.sys têm que estar no mesmo local que o ficheiro *.inf. Não foi encontrado o ficheiro %1</translation>
+        <translation>Os arquivos *.sys têm que estar no mesmo local que o arquivo *.inf. Não foi encontrado o arquivo %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="948"/>
         <source>sys file reference not found</source>
-        <translation>Não foi encontrada a referência do ficheiro sys</translation>
+        <translation>Não foi encontrada a referência do arquivo sys</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="948"/>
         <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
-        <translation>A análise sintáctica (parsing) ao ficheiro inf não permitiu determinar qual é o ficheiro sys para o controlador (driver) em questão</translation>
+        <translation>O processo de análise sintática (parsing) ao arquivo inf não permitiu determinar qual é o arquivo sys para o controlador (driver) em questão</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="967"/>
@@ -392,7 +392,7 @@
     <message>
         <location filename="mainwindow.cpp" line="1016"/>
         <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation>Copyright (c) MEPIS LLC e MX Linux</translation>
+        <translation>Direitos do Autor (c) MEPIS LLC e MX Linux</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1017"/>
@@ -426,7 +426,7 @@
     <message>
         <location filename="main.cpp" line="44"/>
         <source>You must run this program as root.</source>
-        <translation>Este programa deve ser executado como administrador</translation>
+        <translation>Você tem que executar este programa como administrador (root)</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="509"/>
@@ -451,18 +451,18 @@
     <message>
         <location filename="mainwindow.cpp" line="613"/>
         <source>Driver removed from blocklist</source>
-        <translation type="unfinished"/>
+        <translation>Controlador removido da lista de bloqueio</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="614"/>
         <source>Driver removed from blocklist.</source>
-        <translation type="unfinished"/>
+        <translation>Controlador removido da lista de bloqueio</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="620"/>
         <location filename="mainwindow.cpp" line="621"/>
         <source>Module blocked</source>
-        <translation type="unfinished"/>
+        <translation>Módulo bloqueado</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="786"/>
@@ -472,27 +472,27 @@
     <message>
         <location filename="mainwindow.cpp" line="789"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
-        <translation>Detetado um erro, não foi possível compilar o controlador do ndiswrapper.</translation>
+        <translation>Detectado um erro, não foi possível compilar o controlador do NDISwrapper.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="792"/>
         <source>Error detected, could not install ndiswrapper.</source>
-        <translation>Detetado um erro, não foi possível instalar o ndiswrapper.</translation>
+        <translation>Detectado um erro, não foi possível instalar o controlador do NDISwrapper.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="804"/>
         <source>Error encountered while removing Ndiswrapper</source>
-        <translation>Detetado um erro ao remover o Ndiswrapper</translation>
+        <translation>Detectado um erro ao remover o NDISwrapper.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="855"/>
         <source>Unblock Driver</source>
-        <translation type="unfinished"/>
+        <translation>Desbloquear Controlador</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="858"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>Bloquear controlador</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="995"/>
@@ -510,13 +510,13 @@ O(s) dispositivo(s) WiFI podem já estar desbloqueados.</translation>
         <location filename="mainwindow.cpp" line="1040"/>
         <location filename="mainwindow.cpp" line="1041"/>
         <source>Driver loaded successfully</source>
-        <translation>Controlador carregado com êxito</translation>
+        <translation>Controlador carregado com sucesso</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1056"/>
         <location filename="mainwindow.cpp" line="1057"/>
         <source>Driver unloaded successfully</source>
-        <translation>Controlador descarregado com êxito</translation>
+        <translation>Controlador descarregado com sucesso</translation>
     </message>
 </context>
 <context>
@@ -529,7 +529,7 @@ O(s) dispositivo(s) WiFI podem já estar desbloqueados.</translation>
     <message>
         <location filename="mainwindow.cpp" line="669"/>
         <source>Could not unload </source>
-        <translation>Não foi possível descarregar&gt;</translation>
+        <translation>Não foi possível descarregar</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
