@@ -87,7 +87,7 @@
         <location filename="mainwindow.ui" line="409"/>
         <location filename="ui_mainwindow.h" line="775"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>Blokiraj gonilnik</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="428"/>
@@ -312,12 +312,12 @@
     <message>
         <location filename="mainwindow.cpp" line="464"/>
         <source>Blocked Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Blokirani gonilniki</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="486"/>
         <source>Blocked Broadcom Drivers</source>
-        <translation type="unfinished"/>
+        <translation>Blokirani Broadcomm gonilniki</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="894"/>
@@ -426,7 +426,7 @@
     <message>
         <location filename="main.cpp" line="44"/>
         <source>You must run this program as root.</source>
-        <translation>Ta program morate zagnati kot root</translation>
+        <translation>Ta program morate zagnati korensko</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="509"/>
@@ -451,18 +451,18 @@
     <message>
         <location filename="mainwindow.cpp" line="613"/>
         <source>Driver removed from blocklist</source>
-        <translation type="unfinished"/>
+        <translation>Gonilnik je bil odstranjen s seznama blokiranih</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="614"/>
         <source>Driver removed from blocklist.</source>
-        <translation type="unfinished"/>
+        <translation>Gonilnik je bil odstranjen s seznama blokiranih.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="620"/>
         <location filename="mainwindow.cpp" line="621"/>
         <source>Module blocked</source>
-        <translation type="unfinished"/>
+        <translation>Modul je blokiran</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="786"/>
@@ -487,12 +487,12 @@
     <message>
         <location filename="mainwindow.cpp" line="855"/>
         <source>Unblock Driver</source>
-        <translation type="unfinished"/>
+        <translation>Odblokiraj gonilnik</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="858"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>Blokiraj gonilnik</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="995"/>
